'''
% Survival Plot
% This program generates graphs that show the relationship between the survival and age of a population.
%
% This program requires the matplotlib.
%
%    matplotlib ==> http://matplotlib.sourceforge.net/
%
% Last Update: 2011.06.03
% By Jae-Seong Yang, destine@postech.ac.kr
'''

from matplotlib.backends.backend_agg import FigureCanvasAgg as FigureCanvas
from matplotlib.figure import Figure
from matplotlib.lines import Line2D
from matplotlib.patches import Rectangle
import SurvivalData
import matplotlib.font_manager


def SurvivalPlots( prefix, conditions ):
    if len( conditions ) < 6:
        _figsize = (5,3)
    else:
        _figsize = (7.5,4.5)

    color_list = [ 'b', 'r', 'g', 'c', 'm', 'y', 'k' ]
    style_list = [ '-', '--', '-.', ':' ]
    marker_list = [ 'o', '^', 's', 'D', 'v', '<', '>', 'p', '*', 'h', 'H', '+', 'x', 'd' ]

    fig = Figure( figsize=_figsize, dpi = 300 )
    canvas = FigureCanvas(fig)
    ax = fig.add_subplot(111)
    fig.subplots_adjust( top=0.95, bottom=0.15 )
    index = 0
    for aData in conditions:
        c = color_list[ index % len( color_list ) ]
        s = style_list[ index % len( style_list ) ]       
        m = marker_list[ index % len( marker_list ) ]       
        name = aData.name.strip().replace( "\t", " " )
        l, = ax.plot( aData.timelist, aData.survpercent, c+s+m, label = name , linewidth=2)
        l.set_clip_on( False )
        index += 1
    xx = ax.get_xaxis()
    xx.set_ticks_position( "bottom" )
    yy = ax.get_yaxis()
    yy.set_ticks_position( "left" )

    prop = matplotlib.font_manager.FontProperties(size=10) 
    leg = ax.legend( numpoints = 1, prop=prop )
    leg.get_frame().set_alpha(0)
    ax.set_xlabel( "Time (days)" )
    ax.set_ylabel( 'Percent survival' )
    
    fig.savefig('./%s.png' % prefix)
    fig.savefig('./%s.ps' % prefix)
    fig.savefig('./%s.pdf' % prefix)

    ## RAW DATA For Excel
    fout = open( "./%s.txt" % prefix, "w" )
    for aData in conditions:
        fout.write( "%% %s\n" % aData.name )
        fout.write( "Time (days)\tPercent survival\n" )
        for i in range( 0, len( aData.timelist ) ):
            fout.write( "%d\t%f\n" % ( aData.timelist[i], aData.survpercent[i] ) )
        fout.write( "\n" )
    fout.close()


def SurvivalPlot( prefix, aData1, aData2 ):
    if len( conditions ) < 6:
        _figsize = (5,3)
    else:
        _figsize = (7.5,4.5)

    fig = Figure( figsize=_figsize, dpi=300 )
    canvas = FigureCanvas(fig)
    ax = fig.add_subplot(111)
    fig.subplots_adjust( top=0.95, bottom=0.15 )
    name = aData1.name.strip().replace( "\t", " " )
    l, = ax.plot( aData1.timelist, aData1.survpercent, 'bo-', label = name )
    l.set_clip_on( False )
    name = aData2.name.strip().replace( "\t", " " )
    l, = ax.plot( aData2.timelist, aData2.survpercent, 'gD-', label = name )
    l.set_clip_on( False )

    prop = matplotlib.font_manager.FontProperties(size=10) 
    leg = ax.legend( numpoints = 1, prop=prop )
    leg.get_frame().set_alpha(0)
    ax.set_xlabel( "Time (days)" )
    ax.set_ylabel( 'Percent survival' )
    fig.savefig('./%s.png' % prefix)
    fig.savefig('./%s.ps' % prefix)
    fig.savefig('./%s.pdf' % prefix)

    xx = ax.get_xaxis()
    xx.set_ticks_position( "bottom" )
    yy = ax.get_yaxis()
    yy.set_ticks_position( "left" )

    ## RAW DATA For Excel
    fout = open( "./%s.txt" % prefix, "w" )
    fout.write( "%% %s\n" % aData1.name )
    fout.write( "Time (days)\tPercent survival\n" )
    for i in range( 0, len( aData1.timelist ) ):
        fout.write( "%d\t%f\n" % ( aData1.timelist[i], aData1.survpercent[i] ) )

    fout.write( "\n%% %s\n" % aData2.name )
    fout.write( "Time (days)\tPercent survival\n" )
    for i in range( 0, len( aData2.timelist ) ):
        fout.write( "%d\t%f\n" % ( aData2.timelist[i], aData2.survpercent[i] ) )

    fout.close()


if __name__ == "__main__":
    conditions = SurvivalData.ReadDataFromFile( "sample.txt" )

    SurvivalData.CalculateSubplotData( conditions )
    SurvivalPlots( "survival_plot", conditions )

    
